pub unsafe fn init()Expand description
Initializes the global allocator with a heap backed by the HEAP array.
Safety
- This function must be called exactly once before any memory allocation occurs. Calling it multiple times or after allocations have started can lead to undefined behavior.